@@ -26,7 +26,7 @@
 #include "arch.h"
 #include "arch-aarch64.h"
 
-/* NOTE: based on Linux v5.4-rc4 */
+/* NOTE: based on Linux v5.8-rc7 */
 const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "_llseek", __PNR__llseek },
 	{ "_newselect", __PNR__newselect },
@@ -68,7 +68,7 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "clock_settime", 112 },
 	{ "clock_settime64", __PNR_clock_settime64 },
 	{ "clone", 220 },
-	{ "clone3", __PNR_clone3 },
+	{ "clone3", 435 },
 	{ "close", 57 },
 	{ "connect", 203 },
 	{ "copy_file_range", 285 },
@@ -92,6 +92,7 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "exit", 93 },
 	{ "exit_group", 94 },
 	{ "faccessat", 48 },
+	{ "faccessat2", 439 },
 	{ "fadvise64", 223 },
 	{ "fadvise64_64", __PNR_fadvise64_64 },
 	{ "fallocate", 47 },
@@ -159,7 +160,7 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "getresgid32", __PNR_getresgid32 },
 	{ "getresuid", 148 },
 	{ "getresuid32", __PNR_getresuid32 },
-	{ "getrlimit", __PNR_getrlimit },
+	{ "getrlimit", 163 },
 	{ "getrusage", 165 },
 	{ "getsid", 156 },
 	{ "getsockname", 204 },
@@ -266,12 +267,14 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "open_by_handle_at", 265 },
 	{ "open_tree", 428 },
 	{ "openat", 56 },
+	{ "openat2", 437 },
 	{ "pause", __PNR_pause },
 	{ "pciconfig_iobase", __PNR_pciconfig_iobase },
 	{ "pciconfig_read", __PNR_pciconfig_read },
 	{ "pciconfig_write", __PNR_pciconfig_write },
 	{ "perf_event_open", 241 },
 	{ "personality", 92 },
+	{ "pidfd_getfd", 438 },
 	{ "pidfd_open", 434 },
 	{ "pidfd_send_signal", 424 },
 	{ "pipe", __PNR_pipe },
@@ -391,7 +394,7 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "setresuid32", __PNR_setresuid32 },
 	{ "setreuid", 145 },
 	{ "setreuid32", __PNR_setreuid32 },
-	{ "setrlimit", __PNR_setrlimit },
+	{ "setrlimit", 164 },
 	{ "setsid", 157 },
 	{ "setsockopt", 208 },
 	{ "settimeofday", 170 },
