@@ -37,7 +37,7 @@
 #define __SCMP_NR_BASE			__SCMP_NR_OABI_SYSCALL_BASE
 #endif
 
-/* NOTE: based on Linux 4.15-rc7 */
+/* NOTE: based on Linux v5.8-rc7 */
 const struct arch_syscall_def arm_syscall_table[] = { \
 	/* NOTE: arm_sync_file_range() and sync_file_range2() share values */
 	{ "_llseek", (__SCMP_NR_BASE + 140) },
@@ -70,11 +70,17 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "chown32", (__SCMP_NR_BASE + 212) },
 	{ "chroot", (__SCMP_NR_BASE + 61) },
 	{ "clock_adjtime", (__SCMP_NR_BASE + 372) },
+	{ "clock_adjtime64", (__SCMP_NR_BASE + 405) },
 	{ "clock_getres", (__SCMP_NR_BASE + 264) },
+	{ "clock_getres_time64", (__SCMP_NR_BASE + 406) },
 	{ "clock_gettime", (__SCMP_NR_BASE + 263) },
+	{ "clock_gettime64", (__SCMP_NR_BASE + 403) },
 	{ "clock_nanosleep", (__SCMP_NR_BASE + 265) },
+	{ "clock_nanosleep_time64", (__SCMP_NR_BASE + 407) },
 	{ "clock_settime", (__SCMP_NR_BASE + 262) },
+	{ "clock_settime64", (__SCMP_NR_BASE + 404) },
 	{ "clone", (__SCMP_NR_BASE + 120) },
+	{ "clone3", (__SCMP_NR_BASE + 435) },
 	{ "close", (__SCMP_NR_BASE +  6) },
 	{ "connect", (__SCMP_NR_BASE + 283) },
 	{ "copy_file_range", (__SCMP_NR_BASE + 391) },
@@ -98,6 +104,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "exit", (__SCMP_NR_BASE +  1) },
 	{ "exit_group", (__SCMP_NR_BASE + 248) },
 	{ "faccessat", (__SCMP_NR_BASE + 334) },
+	{ "faccessat2", (__SCMP_NR_BASE + 439) },
 	{ "fadvise64", __PNR_fadvise64 },
 	{ "fadvise64_64", __PNR_fadvise64_64 },
 	{ "fallocate", (__SCMP_NR_BASE + 352) },
@@ -118,7 +125,11 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "flock", (__SCMP_NR_BASE + 143) },
 	{ "fork", (__SCMP_NR_BASE +  2) },
 	{ "fremovexattr", (__SCMP_NR_BASE + 237) },
+	{ "fsconfig", (__SCMP_NR_BASE + 431) },
 	{ "fsetxattr", (__SCMP_NR_BASE + 228) },
+	{ "fsmount", (__SCMP_NR_BASE + 432) },
+	{ "fsopen", (__SCMP_NR_BASE + 430) },
+	{ "fspick", (__SCMP_NR_BASE + 433) },
 	{ "fstat", (__SCMP_NR_BASE + 108) },
 	{ "fstat64", (__SCMP_NR_BASE + 197) },
 	{ "fstatat64", (__SCMP_NR_BASE + 327) },
@@ -129,6 +140,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "ftruncate", (__SCMP_NR_BASE + 93) },
 	{ "ftruncate64", (__SCMP_NR_BASE + 194) },
 	{ "futex", (__SCMP_NR_BASE + 240) },
+	{ "futex_time64", (__SCMP_NR_BASE + 422) },
 	{ "futimesat", (__SCMP_NR_BASE + 326) },
 	{ "get_kernel_syms", __PNR_get_kernel_syms },
 	{ "get_mempolicy", (__SCMP_NR_BASE + 320) },
@@ -181,8 +193,12 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "io_destroy", (__SCMP_NR_BASE + 244) },
 	{ "io_getevents", (__SCMP_NR_BASE + 245) },
 	{ "io_pgetevents", (__SCMP_NR_BASE + 399) },
+	{ "io_pgetevents_time64", (__SCMP_NR_BASE + 416) },
 	{ "io_setup", (__SCMP_NR_BASE + 243) },
 	{ "io_submit", (__SCMP_NR_BASE + 246) },
+	{ "io_uring_setup", (__SCMP_NR_BASE + 425) },
+	{ "io_uring_enter", (__SCMP_NR_BASE + 426) },
+	{ "io_uring_register", (__SCMP_NR_BASE + 427) },
 	{ "ioctl", (__SCMP_NR_BASE + 54) },
 	{ "ioperm", __PNR_ioperm },
 	{ "iopl", __PNR_iopl },
@@ -190,7 +206,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "ioprio_set", (__SCMP_NR_BASE + 314) },
 	{ "ipc", __PNR_ipc },
 	{ "kcmp", (__SCMP_NR_BASE + 378) },
-	{ "kexec_file_load", __PNR_kexec_file_load },
+	{ "kexec_file_load", (__SCMP_NR_BASE + 401) },
 	{ "kexec_load", (__SCMP_NR_BASE + 347) },
 	{ "keyctl", (__SCMP_NR_BASE + 311) },
 	{ "kill", (__SCMP_NR_BASE + 37) },
@@ -213,7 +229,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "mbind", (__SCMP_NR_BASE + 319) },
 	{ "membarrier",  (__SCMP_NR_BASE + 389) },
 	{ "memfd_create", (__SCMP_NR_BASE + 385) },
-	{ "migrate_pages", __PNR_migrate_pages },
+	{ "migrate_pages", (__SCMP_NR_BASE + 400) },
 	{ "mincore", (__SCMP_NR_BASE + 219) },
 	{ "mkdir", (__SCMP_NR_BASE + 39) },
 	{ "mkdirat", (__SCMP_NR_BASE + 323) },
@@ -226,6 +242,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "mmap2", (__SCMP_NR_BASE + 192) },
 	{ "modify_ldt", __PNR_modify_ldt },
 	{ "mount", (__SCMP_NR_BASE + 21) },
+	{ "move_mount", (__SCMP_NR_BASE + 429) },
 	{ "move_pages", (__SCMP_NR_BASE + 344) },
 	{ "mprotect", (__SCMP_NR_BASE + 125) },
 	{ "mpx", __PNR_mpx },
@@ -233,7 +250,9 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "mq_notify", (__SCMP_NR_BASE + 278) },
 	{ "mq_open", (__SCMP_NR_BASE + 274) },
 	{ "mq_timedreceive", (__SCMP_NR_BASE + 277) },
+	{ "mq_timedreceive_time64", (__SCMP_NR_BASE + 419) },
 	{ "mq_timedsend", (__SCMP_NR_BASE + 276) },
+	{ "mq_timedsend_time64", (__SCMP_NR_BASE + 418) },
 	{ "mq_unlink", (__SCMP_NR_BASE + 275) },
 	{ "mremap", (__SCMP_NR_BASE + 163) },
 	{ "msgctl", (__SCMP_NR_BASE + 304) },
@@ -258,13 +277,18 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "oldwait4", __PNR_oldwait4 },
 	{ "open", (__SCMP_NR_BASE +  5) },
 	{ "open_by_handle_at", (__SCMP_NR_BASE + 371) },
+	{ "open_tree", (__SCMP_NR_BASE + 428) },
 	{ "openat", (__SCMP_NR_BASE + 322) },
+	{ "openat2", (__SCMP_NR_BASE + 437) },
 	{ "pause", (__SCMP_NR_BASE + 29) },
 	{ "pciconfig_iobase", (__SCMP_NR_BASE + 271) },
 	{ "pciconfig_read", (__SCMP_NR_BASE + 272) },
 	{ "pciconfig_write", (__SCMP_NR_BASE + 273) },
 	{ "perf_event_open", (__SCMP_NR_BASE + 364) },
 	{ "personality", (__SCMP_NR_BASE + 136) },
+	{ "pidfd_getfd", (__SCMP_NR_BASE + 438) },
+	{ "pidfd_open", (__SCMP_NR_BASE + 434) },
+	{ "pidfd_send_signal", (__SCMP_NR_BASE + 424) },
 	{ "pipe", (__SCMP_NR_BASE + 42) },
 	{ "pipe2", (__SCMP_NR_BASE + 359) },
 	{ "pivot_root", (__SCMP_NR_BASE + 218) },
@@ -273,6 +297,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "pkey_mprotect", (__SCMP_NR_BASE + 394) },
 	{ "poll", (__SCMP_NR_BASE + 168) },
 	{ "ppoll", (__SCMP_NR_BASE + 336) },
+	{ "ppoll_time64", (__SCMP_NR_BASE + 414) },
 	{ "prctl", (__SCMP_NR_BASE + 172) },
 	{ "pread64", (__SCMP_NR_BASE + 180) },
 	{ "preadv", (__SCMP_NR_BASE + 361) },
@@ -283,6 +308,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "prof", __PNR_prof },
 	{ "profil", __PNR_profil },
 	{ "pselect6", (__SCMP_NR_BASE + 335) },
+	{ "pselect6_time64", (__SCMP_NR_BASE + 413) },
 	{ "ptrace", (__SCMP_NR_BASE + 26) },
 	{ "putpmsg", __PNR_putpmsg },
 	{ "pwrite64", (__SCMP_NR_BASE + 181) },
@@ -300,6 +326,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "recv", (__SCMP_NR_BASE + 291) },
 	{ "recvfrom", (__SCMP_NR_BASE + 292) },
 	{ "recvmmsg", (__SCMP_NR_BASE + 365) },
+	{ "recvmmsg_time64", (__SCMP_NR_BASE + 417) },
 	{ "recvmsg", (__SCMP_NR_BASE + 297) },
 	{ "remap_file_pages", (__SCMP_NR_BASE + 253) },
 	{ "removexattr", (__SCMP_NR_BASE + 235) },
@@ -317,6 +344,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "rt_sigreturn", (__SCMP_NR_BASE + 173) },
 	{ "rt_sigsuspend", (__SCMP_NR_BASE + 179) },
 	{ "rt_sigtimedwait", (__SCMP_NR_BASE + 177) },
+	{ "rt_sigtimedwait_time64", (__SCMP_NR_BASE + 421) },
 	{ "rt_tgsigqueueinfo", (__SCMP_NR_BASE + 363) },
 	{ "rtas", __PNR_rtas },
 	{ "s390_guarded_storage", __PNR_s390_guarded_storage },
@@ -331,6 +359,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "sched_getparam", (__SCMP_NR_BASE + 155) },
 	{ "sched_getscheduler", (__SCMP_NR_BASE + 157) },
 	{ "sched_rr_get_interval", (__SCMP_NR_BASE + 161) },
+	{ "sched_rr_get_interval_time64", (__SCMP_NR_BASE + 423) },
 	{ "sched_setaffinity", (__SCMP_NR_BASE + 241) },
 	{ "sched_setattr", (__SCMP_NR_BASE + 380) },
 	{ "sched_setparam", (__SCMP_NR_BASE + 154) },
@@ -343,6 +372,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "semget", (__SCMP_NR_BASE + 299) },
 	{ "semop", (__SCMP_NR_BASE + 298) },
 	{ "semtimedop", (__SCMP_NR_BASE + 312) },
+	{ "semtimedop_time64", (__SCMP_NR_BASE + 420) },
 	{ "send", (__SCMP_NR_BASE + 289) },
 	{ "sendfile", (__SCMP_NR_BASE + 187) },
 	{ "sendfile64", (__SCMP_NR_BASE + 239) },
@@ -436,11 +466,15 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "timer_delete", (__SCMP_NR_BASE + 261) },
 	{ "timer_getoverrun", (__SCMP_NR_BASE + 260) },
 	{ "timer_gettime", (__SCMP_NR_BASE + 259) },
+	{ "timer_gettime64", (__SCMP_NR_BASE + 408) },
 	{ "timer_settime", (__SCMP_NR_BASE + 258) },
+	{ "timer_settime64", (__SCMP_NR_BASE + 409) },
 	{ "timerfd", __PNR_timerfd },
 	{ "timerfd_create", (__SCMP_NR_BASE + 350) },
 	{ "timerfd_gettime", (__SCMP_NR_BASE + 354) },
+	{ "timerfd_gettime64", (__SCMP_NR_BASE + 410) },
 	{ "timerfd_settime", (__SCMP_NR_BASE + 353) },
+	{ "timerfd_settime64", (__SCMP_NR_BASE + 411) },
 	{ "times", (__SCMP_NR_BASE + 43) },
 	{ "tkill", (__SCMP_NR_BASE + 238) },
 	{ "truncate", (__SCMP_NR_BASE + 92) },
@@ -462,6 +496,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "ustat", (__SCMP_NR_BASE + 62) },
 	{ "utime", __PNR_utime },
 	{ "utimensat", (__SCMP_NR_BASE + 348) },
+	{ "utimensat_time64", (__SCMP_NR_BASE + 412) },
 	{ "utimes", (__SCMP_NR_BASE + 269) },
 	{ "vfork", (__SCMP_NR_BASE + 190) },
 	{ "vhangup", (__SCMP_NR_BASE + 111) },
