@@ -27,7 +27,7 @@
 #include "arch.h"
 #include "arch-ppc64.h"
 
-/* NOTE: based on Linux 4.15-rc7 */
+/* NOTE: based on Linux v5.8-rc7 */
 const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "_llseek", 140 },
 	{ "_newselect", 142 },
@@ -59,11 +59,17 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "chown32", __PNR_chown32 },
 	{ "chroot", 61 },
 	{ "clock_adjtime", 347 },
+	{ "clock_adjtime64", __PNR_clock_adjtime64 },
 	{ "clock_getres", 247 },
+	{ "clock_getres_time64", __PNR_clock_getres_time64 },
 	{ "clock_gettime", 246 },
+	{ "clock_gettime64", __PNR_clock_gettime64 },
 	{ "clock_nanosleep", 248 },
+	{ "clock_nanosleep_time64", __PNR_clock_nanosleep_time64 },
 	{ "clock_settime", 245 },
+	{ "clock_settime64", __PNR_clock_settime64 },
 	{ "clone", 120 },
+	{ "clone3", 435 },
 	{ "close", 6 },
 	{ "connect", 328 },
 	{ "copy_file_range", 379 },
@@ -87,6 +93,7 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "exit", 1 },
 	{ "exit_group", 234 },
 	{ "faccessat", 298 },
+	{ "faccessat2", 439 },
 	{ "fadvise64", 233 },
 	{ "fadvise64_64", __PNR_fadvise64_64 },
 	{ "fallocate", 309 },
@@ -107,7 +114,11 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "flock", 143 },
 	{ "fork", 2 },
 	{ "fremovexattr", 220 },
+	{ "fsconfig", 431 },
 	{ "fsetxattr", 211 },
+	{ "fsmount", 432 },
+	{ "fsopen", 430 },
+	{ "fspick", 433 },
 	{ "fstat", 108 },
 	{ "fstat64", __PNR_fstat64 },
 	{ "fstatat64", __PNR_fstatat64 },
@@ -118,6 +129,7 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "ftruncate", 93 },
 	{ "ftruncate64", __PNR_ftruncate64 },
 	{ "futex", 221 },
+	{ "futex_time64", __PNR_futex_time64 },
 	{ "futimesat", 290 },
 	{ "get_kernel_syms", 130 },
 	{ "get_mempolicy", 260 },
@@ -170,8 +182,12 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "io_destroy", 228 },
 	{ "io_getevents", 229 },
 	{ "io_pgetevents", 388 },
+	{ "io_pgetevents_time64", __PNR_io_pgetevents_time64 },
 	{ "io_setup", 227 },
 	{ "io_submit", 230 },
+	{ "io_uring_setup", 425 },
+	{ "io_uring_enter", 426 },
+	{ "io_uring_register", 427 },
 	{ "ioctl", 54 },
 	{ "ioperm", 101 },
 	{ "iopl", 110 },
@@ -215,6 +231,7 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "mmap2", __PNR_mmap2 },
 	{ "modify_ldt", 123 },
 	{ "mount", 21 },
+	{ "move_mount", 429 },
 	{ "move_pages", 301 },
 	{ "mprotect", 125 },
 	{ "mpx", 56 },
@@ -222,13 +239,15 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "mq_notify", 266 },
 	{ "mq_open", 262 },
 	{ "mq_timedreceive", 265 },
+	{ "mq_timedreceive_time64", __PNR_mq_timedreceive_time64 },
 	{ "mq_timedsend", 264 },
+	{ "mq_timedsend_time64", __PNR_mq_timedsend_time64 },
 	{ "mq_unlink", 263 },
 	{ "mremap", 163 },
-	{ "msgctl", __PNR_msgctl },
-	{ "msgget", __PNR_msgget },
-	{ "msgrcv", __PNR_msgrcv },
-	{ "msgsnd", __PNR_msgsnd },
+	{ "msgctl", 402 },
+	{ "msgget", 399 },
+	{ "msgrcv", 401 },
+	{ "msgsnd", 400 },
 	{ "msync", 144 },
 	{ "multiplexer", 201 },
 	{ "munlock", 151 },
@@ -247,13 +266,18 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "oldwait4", __PNR_oldwait4 },
 	{ "open", 5 },
 	{ "open_by_handle_at", 346 },
+	{ "open_tree", 428 },
 	{ "openat", 286 },
+	{ "openat2", 437 },
 	{ "pause", 29 },
 	{ "pciconfig_iobase", 200 },
 	{ "pciconfig_read", 198 },
 	{ "pciconfig_write", 199 },
 	{ "perf_event_open", 319 },
 	{ "personality", 136 },
+	{ "pidfd_getfd", 438 },
+	{ "pidfd_open", 434 },
+	{ "pidfd_send_signal", 424 },
 	{ "pipe", 42 },
 	{ "pipe2", 317 },
 	{ "pivot_root", 203 },
@@ -262,6 +286,7 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "pkey_mprotect", 386 },
 	{ "poll", 167 },
 	{ "ppoll", 281 },
+	{ "ppoll_time64", __PNR_ppoll_time64 },
 	{ "prctl", 171 },
 	{ "pread64", 179 },
 	{ "preadv", 320 },
@@ -272,6 +297,7 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "prof", 44 },
 	{ "profil", 98 },
 	{ "pselect6", 280 },
+	{ "pselect6_time64", __PNR_pselect6_time64 },
 	{ "ptrace", 26 },
 	{ "putpmsg", 188 },
 	{ "pwrite64", 180 },
@@ -289,6 +315,7 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "recv", 336 },
 	{ "recvfrom", 337 },
 	{ "recvmmsg", 343 },
+	{ "recvmmsg_time64", __PNR_recvmmsg_time64 },
 	{ "recvmsg", 342 },
 	{ "remap_file_pages", 239 },
 	{ "removexattr", 218 },
@@ -306,6 +333,7 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "rt_sigreturn", 172 },
 	{ "rt_sigsuspend", 178 },
 	{ "rt_sigtimedwait", 176 },
+	{ "rt_sigtimedwait_time64", __PNR_rt_sigtimedwait_time64 },
 	{ "rt_tgsigqueueinfo", 322 },
 	{ "rtas", 255 },
 	{ "s390_guarded_storage", __PNR_s390_guarded_storage },
@@ -320,6 +348,7 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "sched_getparam", 155 },
 	{ "sched_getscheduler", 157 },
 	{ "sched_rr_get_interval", 161 },
+	{ "sched_rr_get_interval_time64", __PNR_sched_rr_get_interval_time64 },
 	{ "sched_setaffinity", 222 },
 	{ "sched_setattr", 355 },
 	{ "sched_setparam", 154 },
@@ -328,10 +357,11 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "seccomp", 358 },
 	{ "security", __PNR_security },
 	{ "select", 82 },
-	{ "semctl", __PNR_semctl },
-	{ "semget", __PNR_semget },
+	{ "semctl", 394 },
+	{ "semget", 393 },
 	{ "semop", __PNR_semop },
-	{ "semtimedop", __PNR_semtimedop },
+	{ "semtimedop", 392 },
+	{ "semtimedop_time64", __PNR_semtimedop_time64 },
 	{ "send", 334 },
 	{ "sendfile", 186 },
 	{ "sendfile64", __PNR_sendfile64 },
@@ -373,10 +403,10 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "setuid32", __PNR_setuid32 },
 	{ "setxattr", 209 },
 	{ "sgetmask", 68 },
-	{ "shmat", __PNR_shmat },
-	{ "shmctl", __PNR_shmctl },
-	{ "shmdt", __PNR_shmdt },
-	{ "shmget", __PNR_shmget },
+	{ "shmat", 397 },
+	{ "shmctl", 396 },
+	{ "shmdt", 398 },
+	{ "shmget", 395 },
 	{ "shutdown", 338 },
 	{ "sigaction", 67 },
 	{ "sigaltstack", 185 },
@@ -425,11 +455,15 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "timer_delete", 244 },
 	{ "timer_getoverrun", 243 },
 	{ "timer_gettime", 242 },
+	{ "timer_gettime64", __PNR_timer_gettime64 },
 	{ "timer_settime", 241 },
+	{ "timer_settime64", __PNR_timer_settime64 },
 	{ "timerfd", __PNR_timerfd },
 	{ "timerfd_create", 306 },
 	{ "timerfd_gettime", 312 },
+	{ "timerfd_gettime64", __PNR_timerfd_gettime64 },
 	{ "timerfd_settime", 311 },
+	{ "timerfd_settime64", __PNR_timerfd_settime64 },
 	{ "times", 43 },
 	{ "tkill", 208 },
 	{ "truncate", 92 },
@@ -451,6 +485,7 @@ const struct arch_syscall_def ppc64_syscall_table[] = { \
 	{ "ustat", 62 },
 	{ "utime", 30 },
 	{ "utimensat", 304 },
+	{ "utimensat_time64", __PNR_utimensat_time64 },
 	{ "utimes", 251 },
 	{ "vfork", 189 },
 	{ "vhangup", 111 },
