@@ -26,7 +26,7 @@
 #include "arch.h"
 #include "arch-x86.h"
 
-/* NOTE: based on Linux v5.4-rc4 */
+/* NOTE: based on Linux v5.8-rc7 */
 const struct arch_syscall_def x86_syscall_table[] = { \
 	{ "_llseek", 140 },
 	{ "_newselect", 142 },
@@ -92,6 +92,7 @@ const struct arch_syscall_def x86_syscall_table[] = { \
 	{ "exit", 1 },
 	{ "exit_group", 252 },
 	{ "faccessat", 307 },
+	{ "faccessat2", 439 },
 	{ "fadvise64", 250 },
 	{ "fadvise64_64", 272 },
 	{ "fallocate", 324 },
@@ -266,12 +267,14 @@ const struct arch_syscall_def x86_syscall_table[] = { \
 	{ "open_by_handle_at", 342 },
 	{ "open_tree", 428 },
 	{ "openat", 295 },
+	{ "openat2", 437 },
 	{ "pause", 29 },
 	{ "pciconfig_iobase", __PNR_pciconfig_iobase },
 	{ "pciconfig_read", __PNR_pciconfig_read },
 	{ "pciconfig_write", __PNR_pciconfig_write },
 	{ "perf_event_open", 336 },
 	{ "personality", 136 },
+	{ "pidfd_getfd", 438 },
 	{ "pidfd_open", 434 },
 	{ "pidfd_send_signal", 424 },
 	{ "pipe", 42 },
